RealtimeReconnectConfig class

Reconnection behavior for the MongoRealtime client.

Constructors

RealtimeReconnectConfig({bool enabled = true, Duration delay = const Duration(seconds: 1), int? maxAttempts, Duration maxDelay = const Duration(seconds: 30), bool useExponentialBackoff = true, bool jitter = true})
const
RealtimeReconnectConfig.disabled()
const

Properties

delay Duration
final
enabled bool
final
hashCode int
The hash code for this object.
no setterinherited
jitter bool
final
maxAttempts int?
final
maxDelay Duration
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
useExponentialBackoff bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited